@@ -5,6 +5,7 @@ context("proj_linpred()")
 ## object -----------------------------------------------------------------
 
 test_that("pl: `object` of class \"projection\" works", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     pl_tester(pls[[tstsetup]],
               nprjdraws_expected = ndr_ncl_dtls(args_prj[[tstsetup]])$nprjdraws,
@@ -81,6 +82,7 @@ test_that(paste(
 test_that(paste(
   "`object` of (informal) class \"proj_list\" (created manually) works"
 ), {
+  skip_if_not(run_prj)
   tstsetups <- grep("\\.glm\\.gauss\\..*\\.clust$", names(prjs), value = TRUE)
   stopifnot(length(tstsetups) > 1)
   pl <- proj_linpred(prjs[tstsetups])
@@ -92,6 +94,7 @@ test_that(paste(
 test_that(paste(
   "`object` of class \"refmodel\" and passing arguments to project() works"
 ), {
+  skip_if_not(run_prj)
   tstsetups <- grep("\\.glm\\.gauss.*\\.solterms_x\\.clust$", names(prjs),
                     value = TRUE)
   for (tstsetup in tstsetups) {
@@ -109,6 +112,7 @@ test_that(paste(
   "`object` of class \"stanreg\" or \"brmsfit\" and passing arguments to",
   "project() works"
 ), {
+  skip_if_not(run_prj)
   tstsetups <- grep("\\.glm\\.gauss.*\\.solterms_x\\.clust$", names(prjs),
                     value = TRUE)
   for (tstsetup in tstsetups) {
@@ -178,16 +182,19 @@ test_that("`object` not of class \"vsel\" and missing `solution_terms` fails", {
     paste("^Please provide an `object` of class \"vsel\" or use argument",
           "`solution_terms`\\.$")
   )
-  expect_error(
-    proj_linpred(c(prjs, list(dat))),
-    paste("Please provide an `object` of class \"vsel\" or use argument",
-          "`solution_terms`\\.")
-  )
+  if (run_prj) {
+    expect_error(
+      proj_linpred(c(prjs, list(dat))),
+      paste("Please provide an `object` of class \"vsel\" or use argument",
+            "`solution_terms`\\.")
+    )
+  }
 })
 
 ## newdata and integrated -------------------------------------------------
 
 test_that("invalid `newdata` fails", {
+  skip_if_not(run_prj)
   expect_error(
     proj_linpred(prjs, newdata = dat[, 1]),
     "must be a data\\.frame or a matrix"
@@ -202,6 +209,7 @@ test_that("invalid `newdata` fails", {
 })
 
 test_that("`newdata` and `integrated` work (even in edge cases)", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     ndr_ncl <- ndr_ncl_dtls(args_prj[[tstsetup]])
     dat_crr <- get_dat(tstsetup)
@@ -230,6 +238,7 @@ test_that("`newdata` and `integrated` work (even in edge cases)", {
 })
 
 test_that("`newdata` set to the original dataset doesn't change results", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     dat_crr <- get_dat(tstsetup)
     pl_newdata <- proj_linpred(prjs[[tstsetup]], newdata = dat_crr)
@@ -243,6 +252,7 @@ test_that(paste(
   "reference models) causes output element `lpd` to be `NULL` but doesn't",
   "change results otherwise"
 ), {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     if (args_prj[[tstsetup]]$pkg_nm == "brms") {
       next
@@ -269,6 +279,7 @@ test_that(paste(
 ## weightsnew -------------------------------------------------------------
 
 test_that("`weightsnew` works", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     ndr_ncl <- ndr_ncl_dtls(args_prj[[tstsetup]])
     pl_orig <- pls[[tstsetup]]
@@ -355,6 +366,7 @@ test_that("`weightsnew` works", {
 ## offsetnew --------------------------------------------------------------
 
 test_that("`offsetnew` works", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     ndr_ncl <- ndr_ncl_dtls(args_prj[[tstsetup]])
     pl_orig <- pls[[tstsetup]]
@@ -429,6 +441,7 @@ test_that("`offsetnew` works", {
 ## transform --------------------------------------------------------------
 
 test_that("`transform` works", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     ndr_ncl <- ndr_ncl_dtls(args_prj[[tstsetup]])
     pl_false <- pls[[tstsetup]]
@@ -445,6 +458,7 @@ test_that("`transform` works", {
 ## regul ------------------------------------------------------------------
 
 test_that("`regul` works", {
+  skip_if_not(run_prj)
   regul_tst <- c(1e-6, 1e-1, 1e2)
   stopifnot(identical(regul_tst, sort(regul_tst)))
   tstsetups <- grep("\\.glm\\..*\\.solterms_x\\.clust$", names(prjs),
@@ -472,6 +486,7 @@ test_that("`regul` works", {
 ## filter_nterms ----------------------------------------------------------
 
 test_that("`filter_nterms` works (for an `object` of class \"projection\")", {
+  skip_if_not(run_prj)
   tstsetups <- grep("\\.glm\\.gauss.*\\.solterms_x\\.clust$", names(prjs),
                     value = TRUE)
   for (tstsetup in tstsetups) {
@@ -537,6 +552,7 @@ test_that(paste(
   "a single observation and a single draw work (which implicitly tests",
   "this edge case for family$ll_fun(), too)"
 ), {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     if (args_prj[[tstsetup]]$mod_nm == "gamm") {
       # TODO (GAMMs): Fix this.
@@ -561,6 +577,7 @@ context("proj_predict()")
 ## seed -------------------------------------------------------------------
 
 test_that("`.seed` works (and restores the RNG state afterwards)", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     .Random.seed_orig1 <- .Random.seed
     pp_orig <- pps[[tstsetup]]
@@ -603,6 +620,7 @@ test_that("`.seed` works (and restores the RNG state afterwards)", {
 ## object -----------------------------------------------------------------
 
 test_that("pp: `object` of class \"projection\" works", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     pp_tester(pps[[tstsetup]],
               nprjdraws_out_expected =
@@ -680,6 +698,7 @@ test_that(paste(
 test_that(paste(
   "`object` of (informal) class \"proj_list\" (created manually) works"
 ), {
+  skip_if_not(run_prj)
   tstsetups <- grep("\\.glm\\.gauss\\..*\\.clust$", names(prjs), value = TRUE)
   stopifnot(length(tstsetups) > 1)
   pp <- proj_predict(prjs[tstsetups], .seed = seed2_tst)
@@ -691,6 +710,7 @@ test_that(paste(
 test_that(paste(
   "`object` of class \"refmodel\" and passing arguments to project() works"
 ), {
+  skip_if_not(run_prj)
   tstsetups <- grep("\\.glm\\.gauss.*\\.solterms_x\\.clust$", names(prjs),
                     value = TRUE)
   for (tstsetup in tstsetups) {
@@ -709,6 +729,7 @@ test_that(paste(
   "`object` of class \"stanreg\" or \"brmsfit\" and passing arguments to",
   "project() works"
 ), {
+  skip_if_not(run_prj)
   tstsetups <- grep("\\.glm\\.gauss.*\\.solterms_x\\.clust$", names(prjs),
                     value = TRUE)
   for (tstsetup in tstsetups) {
@@ -781,16 +802,19 @@ test_that("`object` not of class \"vsel\" and missing `solution_terms` fails", {
     paste("^Please provide an `object` of class \"vsel\" or use argument",
           "`solution_terms`\\.$")
   )
-  expect_error(
-    proj_predict(c(prjs, list(dat)), .seed = seed2_tst),
-    paste("Please provide an `object` of class \"vsel\" or use argument",
-          "`solution_terms`\\.")
-  )
+  if (run_prj) {
+    expect_error(
+      proj_predict(c(prjs, list(dat)), .seed = seed2_tst),
+      paste("Please provide an `object` of class \"vsel\" or use argument",
+            "`solution_terms`\\.")
+    )
+  }
 })
 
 ## newdata and nresample_clusters -----------------------------------------
 
 test_that("invalid `newdata` fails", {
+  skip_if_not(run_prj)
   expect_error(
     proj_predict(prjs, newdata = dat[, 1], .seed = seed2_tst),
     "must be a data\\.frame or a matrix"
@@ -807,6 +831,7 @@ test_that("invalid `newdata` fails", {
 })
 
 test_that("`newdata` and `nresample_clusters` work (even in edge cases)", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     for (nobsv_crr in nobsv_tst) {
       if (args_prj[[tstsetup]]$mod_nm == "gamm") {
@@ -831,6 +856,7 @@ test_that("`newdata` and `nresample_clusters` work (even in edge cases)", {
 })
 
 test_that("`newdata` set to the original dataset doesn't change results", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     pp_newdata <- proj_predict(prjs[[tstsetup]],
                                newdata = dat,
@@ -844,6 +870,7 @@ test_that(paste(
   "omitting the response in `newdata` (not possible for `\"brmsfit\"`-based",
   "reference models) doesn't change results"
 ), {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     if (args_prj[[tstsetup]]$pkg_nm == "brms") {
       next
@@ -863,6 +890,7 @@ test_that(paste(
 ## weightsnew -------------------------------------------------------------
 
 test_that("`weightsnew` works", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     ndr_ncl <- ndr_ncl_dtls(args_prj[[tstsetup]])
     pp_orig <- pps[[tstsetup]]
@@ -931,6 +959,7 @@ test_that("`weightsnew` works", {
 ## offsetnew --------------------------------------------------------------
 
 test_that("`offsetnew` works", {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     ndr_ncl <- ndr_ncl_dtls(args_prj[[tstsetup]])
     pp_orig <- pps[[tstsetup]]
@@ -1008,6 +1037,7 @@ test_that("`offsetnew` works", {
 ## filter_nterms ----------------------------------------------------------
 
 test_that("`filter_nterms` works (for an `object` of class \"projection\")", {
+  skip_if_not(run_prj)
   tstsetups <- grep("\\.glm\\.gauss.*\\.solterms_x\\.clust$", names(prjs),
                     value = TRUE)
   for (tstsetup in tstsetups) {
@@ -1077,6 +1107,7 @@ test_that(paste(
   "a single observation and a single draw work (which implicitly tests",
   "this edge case for family$ppd(), too)"
 ), {
+  skip_if_not(run_prj)
   for (tstsetup in names(prjs)) {
     if (args_prj[[tstsetup]]$mod_nm == "gamm") {
       # TODO (GAMMs): Fix this.
